Rename Host/Runtime hostname fields to Outside/Inside pattern

This renames all hostname/OS/working directory fields to follow the
Outside/Inside naming pattern rather than Host/Runtime naming pattern.

- HostHostname -> OutsideHostname
- RuntimeHostname -> InsideHostname
- HostOS -> OutsideOS
- RuntimeOS -> InsideOS
- HostWorkingDir -> OutsideWorkingDir
- RuntimeWorkingDir -> InsideWorkingDir

This includes related method names, struct fields, and JavaScript properties.

Co-Authored-By: sketch
diff --git a/dockerimg/dockerimg.go b/dockerimg/dockerimg.go
index 3a839e0..c2fd1c5 100644
--- a/dockerimg/dockerimg.go
+++ b/dockerimg/dockerimg.go
@@ -79,10 +79,10 @@
 	// Private key used to identify the container's ssh server
 	SSHServerIdentity []byte
 
-	// Host information to pass to the container
-	HostHostname   string
-	HostOS         string
-	HostWorkingDir string
+	// Outside information to pass to the container
+	OutsideHostname   string
+	OutsideOS         string
+	OutsideWorkingDir string
 }
 
 // LaunchContainer creates a docker container for a project, installs sketch and opens a connection to it.
@@ -410,9 +410,9 @@
 		"-session-id="+config.SessionID,
 		"-git-username="+config.GitUsername,
 		"-git-email="+config.GitEmail,
-		"-host-hostname="+config.HostHostname,
-		"-host-os="+config.HostOS,
-		"-host-working-dir="+config.HostWorkingDir,
+		"-outside-hostname="+config.OutsideHostname,
+		"-outside-os="+config.OutsideOS,
+		"-outside-working-dir="+config.OutsideWorkingDir,
 	)
 	if config.SkabandAddr != "" {
 		cmdArgs = append(cmdArgs, "-skaband-addr="+config.SkabandAddr)